<?php
/*  Copyright 2011  Michael J. Walker (email: mike@moztools.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
    
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

include_once 'moztools/mozadmin.php';

class MozTheme2011Admin extends MozAdminBaseClass_MozTheme2011 {

    protected $adminMenu = 'appearance';
    protected $adminTitle = 'Twenty Eleven Theme Extensions';
    protected $adminMenuTitle = 'Theme Extensions';
    protected $adminMenuSlug = 'moztheme2011';
    
    protected $pluginOptions = MOZTHEME2011_OPTIONS;
    
    protected $store;

    public static function create() {
        if (strpos(get_current_theme(), MOZTHEME2011_NAME) !== false) {
            new MozTheme2011Admin();
        }
    }

    protected function __construct() {
        parent::__construct();
        if ($this->isAdminPage()) {
            $this->registerScripts('moztheme2011admin.min', array('jquery-ui-widget'));
            $this->registerStyles('moztheme2011admin');
        }
    }

    protected function init() {
        parent::init();
        $this->registerFilter('twentyeleven_header_image_height', 'getHeaderImageHeight');
    }

    public function getHeaderImageHeight($height) {
        return $this->isOptionSet('image-size') ? $this->getOption('image-height') : $height;
    }
    
    public function displayAdminPage() {
        $this->setFormData($this->getOptions());
        $row = $this->checkBox('sidebar-page', 'Enable the widget sidebar on pages').$this->crlf();
        $row .= $this->checkBox('sidebar-post', 'Enable the widget sidebar on single-post pages').$this->crlf();
        $indent = $this->checkBox('adjust-nav', 'Center the navigation links at the top of single-post pages', true);
        $row .= $this->wrapIndent($indent); 
        $content = $this->wrapRow($row, 'Widget Sidebar', 'moz-sidebars');

        $row = $this->checkBox('align-widget-titles', 'Left align the widget titles with the contents of the widgets.');
        $content .= $this->wrapRow($row, 'Widget Titles', 'moz-widget-titles');

        $row = $this->checkBox('headline', 'Enable sticky post as headline').$this->crlf();
        $indent = $this->textInput('headline-text', 'Enter text to display with the sticky post\'s title', '',
                                   '<em>(Note: place the string <strong>%title%</strong> where you want the post title to appear in the text)</em>', true);
        $row .= $this->wrapIndent($indent);
        $content .= $this->wrapRow($row, 'Headline Post', 'moz-headlines');

        $row = $this->checkBox('image-size', 'Change the height of new images created on the <strong>Header</strong> admin page').$this->crlf();
        $indent = $this->textInput('image-height', 'Height (in pixels)', '288', '', true).$this->crlf();
        $indent .= $this->checkBox('force-image-size', 'Force all existing header images to be this height.'.$this->crlf()
                                  .'<em class="moz-indent">(Warning: requires Javascript, and will stretch or compress images of with different heights)</em>', true).$this->crlf();
        $row .= $this->wrapIndent($indent);
        $content .= $this->wrapRow($row, 'Header Image Size', 'moz-image-size');

        $row = $this->checkBox('embed-custom-css', 'Include custom CSS styles for the blog').$this->crlf();
        $indent = $this->textArea('custom-css', 10, 'Enter one or more CSS styles to use with your blog:', '', true);
        $row .= $this->wrapIndent($indent);
        $content .= $this->wrapRow($row, 'Custom CSS', 'moz-custom-css');

        $content = $this->wrapTable($content);
        $content .= $this->helpText('moztheme2011help');
        $content .= $this->hiddenInput('action', 'save');
        $content .= $this->submitButton('submit', 'Save Changes'); 
        $content = $this->wrapForm($content, $this->getAdminUrl());
        $content = $this->title('icon-themes', 'Twenty Eleven Theme Extensions <em>(by MozTools)</em>').$content;
        $content .= '<div id="settings-container" />';
        $content = $this->wrapClass($content, 'wrap');
        echo $content;
    }
    
    protected function processAdminRequest($action, $params) {
        $this->updateOptions($params);
    }
}